@@ -82,6 +82,12 @@ class Environment(AcquiaResource):
     ) -> Session:
         """
         Create a log forwarding destination.
+        :param label: Human-friendly identifier of the destination
+        :param sources: List of log sources to forward
+        :param consumer: Application or provider consuming the logs.
+        :param credentials: Dictionary of certificate,key and token.
+        :param address: URL or host name and port of the destination.
+        :param destination_uuid: Log forwarding destination uuid for given env.
         """
         uri = f"{self.uri}/log-forwarding-destinations"
         data = {
@@ -102,6 +108,16 @@ class Environment(AcquiaResource):
         uri = f"{self.uri}/databases"
         return self.request(uri=uri, method="GET").json()
 
+    def delete_backup(self, db_name: str, backup_id: str) -> Session:
+        """
+        Delete a backup
+
+        :param db_name: Database name, typically lower snake case.
+        :param backup_id: Database backup id.
+        """
+        uri = f"{self.uri}/databases/{db_name}/backups/{backup_id}"
+        return self.request(uri=uri, method="DELETE").json()
+
     def delete_domain(self, domain: str) -> Session:
         """
         Remove the domain from the environment.
@@ -113,6 +129,20 @@ class Environment(AcquiaResource):
 
         return response
 
+    def delete_log_forwarding_destinations(
+        self,
+        destination_uuid: str,
+    ) -> Session:
+        """
+        Delete a log forwarding destination.
+
+        :param destination_uuid: log forwarding destination uuid for given env.
+        """
+        uri = f"{self.uri}/log-forwarding-destinations/{destination_uuid}"
+        response = self.request(uri=uri, method="DELETE")
+
+        return response
+
     def clear_varnish_domain(self, domain: str) -> Session:
         """
         Clear the Varnish cache for the domain attached to this environment.
@@ -243,3 +273,33 @@ class Environment(AcquiaResource):
         }
 
         return self.configure(data)
+
+    def update_log_forwarding_destinations(
+        self,
+        label: str,
+        sources: list,
+        consumer: str,
+        credentials: dict,
+        address: str,
+        destination_uuid: str,
+    ) -> Session:
+        """
+        Update a log forwarding destination.
+        :param label: Human-friendly identifier of the destination
+        :param sources: List of log sources to forward
+        :param consumer: Application or provider consuming the logs.
+        :param credentials: Dictionary of certificate,key and token.
+        :param address: URL or host name and port of the destination.
+        :param destination_uuid: Log forwarding destination uuid for given env.
+        """
+        uri = f"{self.uri}/log-forwarding-destinations/{destination_uuid}"
+        data = {
+            "label": label,
+            "sources": sources,
+            "consumer": consumer,
+            "credentials": credentials,
+            "address": address,
+        }
+        response = self.request(uri=uri, method="PUT", data=data)
+
+        return response
