@@ -412,6 +412,37 @@ class TestEnvironments(BaseTest):
         self.assertEqual(response.status_code, 202)
         self.assertIn(b"created", response.content)
 
+    def test_delete_backup(self, mocker):
+        env_id = "12-d314739e-296f-11e9-b210-d663bd873d93"
+        db_name = "my_db"
+        uri = f"{self.endpoint}/environments/{env_id}/" \
+              f"databases/{db_name}/backups/1"
+
+        response = {
+            "message": "Deleting the database backup.",
+            "_links": {
+                "self": {
+                    "href": "https://cloud.acquia.com/api/environments/12-d314"
+                            "739e-296f-11e9-b210-d663bd873d93/databases/"
+                            "my_db/backups/1"
+                },
+                "notification": {
+                    "href": "https://cloud.acquia.com/api/notifications/42b5"
+                            "6cff-0b55-4bdf-a949-1fd0fca61c6c"
+                },
+                "parent": {
+                    "href": "https://cloud.acquia.com/api/environments/12-d31"
+                            "4739e-296f-11e9-b210-d663bd873d93/databases/"
+                            "my_db/backups"
+                }
+            }
+        }
+
+        mocker.register_uri("DELETE", uri, status_code=202, json=response)
+        response = self.acquia.environment(env_id).delete_backup(db_name, 1)
+        self.assertEqual(response["message"], "Deleting the database backup.")
+        self.assertIn("_links", response)
+
     def test_delete_domain(self, mocker):
         env_id = "24-a47ac10b-58cc-4372-a567-0e02b2c3d470"
         domain = "ceruleanhq.com"
@@ -464,6 +495,25 @@ class TestEnvironments(BaseTest):
 
         self.assertEqual(response.status_code, 202)
 
+    def test_delete_log_forwarding_destinations(self, mocker):
+        env_id = "24-a47ac10b-58cc-4372-a567-0e02b2c3d470"
+        destination_uuid = "df4c5428-8d2e-453d-9edf-e412647449b1"
+        uri = f"{self.endpoint}/environments/{env_id}/"\
+              f"log-forwarding-destinations/{destination_uuid}"
+
+        response_message = {
+            "message": "Log forwarding destination has been deleted."
+        }
+
+        mocker.register_uri("DELETE", uri,
+                            status_code=202, json=response_message)
+
+        response = self.acquia.environment(
+            env_id).delete_log_forwarding_destinations(destination_uuid)
+
+        self.assertEqual(response.status_code, 202)
+        self.assertIn(b"deleted", response.content)
+
     def test_destroy(self, mocker):
         env_id = "24-a47ac10b-58cc-4372-a567-0e02b2c3d470"
         uri = "{base_uri}/environments/{env_id}"
@@ -855,3 +905,35 @@ class TestEnvironments(BaseTest):
 
         self.assertEqual(response.status_code, 202)
         self.assertIn(b"updated", response.content)
+
+    def test_update_log_forwarding_destinations(self, mocker):
+        env_id = "24-a47ac10b-58cc-4372-a567-0e02b2c3d470"
+        destination_uuid = "df4c5428-8d2e-453d-9edf-e412647449b1"
+        uri = f"{self.endpoint}/environments/{env_id}/"\
+              f"log-forwarding-destinations/{destination_uuid}"
+
+        response_message = {
+            "message": "Log forwarding destination has been updated."
+        }
+
+        mocker.register_uri("PUT", uri,
+                            status_code=202, json=response_message)
+
+        label = "Test destination"
+        sources = [
+            "apache-access",
+            "apache-error"
+        ]
+        consumer = "syslog"
+        credentials = {
+            "certificate": "-----BEGIN CERTIFICATE-----...\
+            -----END CERTIFICATE-----"
+        }
+        address = "example.com:1234"
+
+        response = self.acquia.environment(
+            env_id).update_log_forwarding_destinations(
+            label, sources, consumer, credentials, address, destination_uuid)
+
+        self.assertEqual(response.status_code, 202)
+        self.assertIn(b"updated", response.content)
